<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package filepress
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 *
 * @return array
 */
function filepress_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}

add_filter( 'body_class', 'filepress_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function filepress_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}

add_action( 'wp_head', 'filepress_pingback_header' );


//attach our function to the wp_pagenavi filter
add_filter( 'wp_pagenavi', 'roman_pagination', 10, 2 );

//customize the PageNavi HTML before it is output
function roman_pagination( $html ) {
	$out = '';

	//wrap a's and span's in li's
	$out = str_replace( "<div", "", $html );
	$out = str_replace( "class='wp-pagenavi'>", "", $out );
	$out = str_replace( "<a", "<li><a", $out );
	$out = str_replace( "</a>", "</a></li>", $out );
	$out = str_replace( "<span", "<li><span", $out );
	$out = str_replace( "</span>", "</span></li>", $out );
	$out = str_replace( "</div>", "", $out );

	return '<ul class="pagination pagination-centered">' . $out . '</ul>';
}


function _roman_jdate( $format, $time ) {
	if ( function_exists( 'jdate' ) ) {
		return jdate( $format, $time );
	} elseif ( class_exists( 'bn_parsidate' ) ) {
		$bndate = bn_parsidate::getInstance();

		return $bndate = $bndate->persian_date( $format, $time );
	} elseif ( class_exists( 'IntlDateFormatter' ) ) {
		return new IntlDateFormatter( 'fa@calendar=persian', IntlDateFormatter::FULL, IntlDateFormatter::FULL, 'GMT', IntlDateFormatter::TRADITIONAL, 'EEEE dd MMMM yyyy' );

	} else {
		return date( $format, $time );
	}

}


/**
 * View Counter
 */
// function to display number of posts.
function roman_getPostViews( $postID ) {
	$count_key = 'post_views_count';
	$count     = get_post_meta( $postID, $count_key, true );
	if ( $count == '' ) {
		delete_post_meta( $postID, $count_key );
		add_post_meta( $postID, $count_key, '0' );

		return "0";
	}

	return $count;
}

// function to count views.
function roman_setPostViews( $postID ) {
	$count_key = 'post_views_count';
	$count     = get_post_meta( $postID, $count_key, true );
	if ( $count == '' ) {
		$count = 0;
		delete_post_meta( $postID, $count_key );
		add_post_meta( $postID, $count_key, '0' );
	} else {
		$count ++;
		update_post_meta( $postID, $count_key, $count );
	}
}


// Add it to a column in WP-Admin
add_filter( 'manage_posts_columns', 'roman_posts_column_views' );
add_action( 'manage_posts_custom_column', 'roman_posts_custom_column_views', 5, 2 );
function roman_posts_column_views( $defaults ) {
	$defaults['post_views'] = __( 'بازدید' );

	return $defaults;
}

function roman_posts_custom_column_views( $column_name, $id ) {
	if ( $column_name === 'post_views' ) {
		echo roman_getPostViews( get_the_ID() );
	}
}


add_action( 'after_switch_theme', 'roman_after_switch_theme' );
function roman_after_switch_theme() {
	if ( get_option( 'filepress_starpostrating_translated' ) != '1' ) {
		update_option( 'postratings_options', array( 'richsnippet' => 1 ) ); // 1,0
		update_option( 'postratings_template_vote', '%RATINGS_IMAGES_VOTE%  %RATINGS_SCORE% امتیاز %RATINGS_TEXT%' ); // %RATINGS_IMAGES_VOTE%  %RATINGS_SCORE% امتیاز %RATINGS_TEXT%
		update_option( 'postratings_template_text', '%RATINGS_IMAGES% %RATINGS_SCORE% امتیاز' ); // %RATINGS_IMAGES% %RATINGS_SCORE% امتیاز
		update_option( 'postratings_template_none', '%RATINGS_IMAGES_VOTE%' ); // %RATINGS_IMAGES_VOTE%
		//add
		update_option( 'filepress_starpostrating_translated', '1' );
	}
}

/**
 * Add custom css to site
 */
add_action( 'wp_head', 'filepress_styles_css' );
function filepress_styles_css() {
	global $filepress;
	$css = '';

	//logo
	if ( isset( $filepress['opt-header-img']['url'] ) && ! empty( $filepress['opt-header-img']['url'] ) ) {
		$css .= '.page_index .header_td_lte{background-image:url("' . $filepress['opt-header-img']['url'] . '");}';
	}


	echo '<style>' . $css . '</style>';

}

/**
 * To fetch roman post meta
 *
 * @param int post_id
 *
 * @return string
 */

function roman_get_meta( $post_id, $key ) {
	$roman_dll_box = get_post_meta( $post_id, '_roman_dll_box_fields', true );
	if ( $key == 'genre' && isset( $roman_dll_box[ $key ] ) ) {
		$cat_name = get_cat_name( $roman_dll_box[ $key ] );
		$cat_link = get_category_link( $roman_dll_box[ $key ] );
		if ( empty( $cat_name ) || empty( $cat_link ) ) {
			return false;
		}

		return '<a href="' . $cat_link . '">' . $cat_name . '</a>';
	}
	if ( isset( $roman_dll_box[ $key ] ) ) {
		return $roman_dll_box[ $key ];
	}

	return false;
}

/**
 * Get Categories in html
 * @return string
 */
function roman_get_categories_select_html( $name, $selected = false ) {
	$teh_cats = get_categories( array( 'hide_empty' => 0 ) );
	$results  = '';
	$results  .= '<select name="' . $name . '">';
	$count    = count( $teh_cats );
	for ( $i = 0; $i < $count; $i ++ ) {
		if ( isset( $teh_cats[ $i ] ) ) {
			$results .= '<option value="' . $teh_cats[ $i ]->term_id . '" ';
			if ( $selected ) {
				if ( $selected == $teh_cats[ $i ]->term_id ) {
					$results .= ' selected="selected" ';
				}

			}
			$results .= '>';
			$results .= $teh_cats[ $i ]->name;
			$results .= '</option>';

		} else {
			$count ++;
		}

	}
	$results .= '</select>';

	return $results;
}


/**
 * [roman_get_slideshow_items description]
 *
 * @param  int $cat_id
 *
 * @return array         array of post objects
 */
function roman_get_slideshow_items( $cat_id ) {
	$services = array();
	$num      = 5;

	// The Query
	$the_query = new WP_Query( array(
		'cat'            => $cat_id,
		'post_type'      => 'post',
		'posts_per_page' => $num,
		'orderby'        => 'date',
		'order'          => 'DESC'
	) );

	// The Loop
	if ( $the_query->have_posts() ) {
		while ( $the_query->have_posts() ) {
			$the_query->the_post();
			$services[] = get_post();
		}
		/* Restore original Post Data */
		wp_reset_postdata();
	}

	return $services;
}
/**
 * برای نمایش محصول تکی در ارشیو
 */
function filepress_view_download($post_id)
{
	global $post;
	?>
  <div class="col-md-4 col-sm-4 col-xs-6 mahsolat_wrapper">
      <li class=" product animated " data-animated="fadeInUp">
          <a href="<?php the_permalink(); ?>">
              <div class="hovereffect">
                <?php if ( has_post_thumbnail() ) { ?>

                    <?php the_post_thumbnail( 'product-img' ); ?>

                <?php }else{
                    ?>
                      <img src="<?php echo get_template_directory_uri(); ?>/layouts/img/book.png"
                           alt="عکس کالای موجود" width="180">
                      <?php
                  } ?>


                  <div class="overlay">
                      <i class="fa fa-link"></i>
                      <p class="">توضیحات بیشتر</p>
                  </div>
              </div>
              <p class="name_product"><?= the_title(); ?></p>
              <hr class="online_store_cmn_sep">
          </a>
          <span class="price">
<!--                                                                         <p><del><span class="">--><?php //edd_price(get_the_ID()); ?><!--<span class="">تومان</span></span>-->
<!--                                                                        </del>-->
<!--                                                                        </p>-->
                            <?php $item_props = edd_add_schema_microdata() ? ' itemprop="offers" itemscope itemtype="http://schema.org/Offer"' : ''; ?>
                              <span <?php echo $item_props; ?> class="woocommerce-Price-amount amount"><?php edd_price(get_the_ID()); ?>
                                  <span class="price_index woocommerce-Price-currencySymbol"></span></span>
                              </span>
          <div class="kharid">
              <a class="edame_matlab" type="button" href="<?php the_permalink(); ?>">دانلود<i
                          class="fa fa-download"></i></a>
              <div class="clearfix"></div>
              <span class="interested"><i class="fa fa-heart "></i></span>
          </div>
      </li>
  </div>
	<?php
}

/**
 * Get downloads by category
 */
function filepress_cat_section( $cat_id, $num = 6 ) {

	$cat = get_term( $cat_id, 'download_category' );
	if(!$cat) return;
//	var_dump($cat);
	$args = array(
	 'post_type' => 'download',
	 'posts_per_page' => $num,
		'tax_query' => array(
			array(
				'taxonomy' => 'download_category',
				'field'    => 'slug',
				'terms'    => $cat->slug,
			),
		)
	 );
	$q    = new wp_query( $args );
	if ( $q->have_posts() ) {
		?>
        <div class="widget_wrapper catalogs_slider_wrapper">
            <div class="widget_title">
                <div class="border_top"></div>
                <div class="border_right"></div>
                <h3><?= $cat->name; ?></h3>
                <p><?= $cat->description; ?></p>
            </div>
            <div class="widget_content">
                <div class="products-carousel woocommerce">
                    <div id="products_sliders_<?= $cat_id ;?>" class="carousel slide">
                        <ul class="carousel-inner">
                            <div class="item active">
                                <div class="row">
                                    <ul class="ul-products-lists">
                                        <?php
                                        while ( $q->have_posts() ) {
	                                        $q->the_post();
	                                         filepress_view_download(get_the_ID());
                                        }
                                        ?>

                                    </ul>
                                </div>
                            </div>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
		<?php
	}
}


function filepress_edd_product_supports($supports) {
	$supports[] = 'comments';
	return $supports;	
}
add_filter('edd_download_supports', 'filepress_edd_product_supports');


/**
 * Remove the edd contents after post since we own attached is before.
 */
remove_action( 'edd_after_download_content', 'edd_append_purchase_link' );



function filepress_main_sidebar_class()
{
	global $filepress;
	if(isset($filepress['opt-enable-sidebar']) && $filepress['opt-enable-sidebar']!=1)
	{
		return 'col-md-12 col-sm-12 col-xs-12 soton_chap';
	}else{
		return 'col-md-9 col-md-push-3 col-sm-12 col-xs-12 soton_chap';
	}
}
/**
 * https://stackoverflow.com/a/11951022
 * @param  color $hex   #fffddd
 * @param  range $steps  Steps should be between -255 and 255. Negative = darker, positive = lighter
 * @return string        converted color
 */
function filepress_adjustBrightness($hex, $steps) {
    // Steps should be between -255 and 255. Negative = darker, positive = lighter
    $steps = max(-255, min(255, $steps));

    // Normalize into a six character long hex string
    $hex = str_replace('#', '', $hex);
    if (strlen($hex) == 3) {
        $hex = str_repeat(substr($hex,0,1), 2).str_repeat(substr($hex,1,1), 2).str_repeat(substr($hex,2,1), 2);
    }

    // Split into three parts: R, G and B
    $color_parts = str_split($hex, 2);
    $return = '#';

    foreach ($color_parts as $color) {
        $color   = hexdec($color); // Convert to decimal
        $color   = max(0,min(255,$color + $steps)); // Adjust color
        $return .= str_pad(dechex($color), 2, '0', STR_PAD_LEFT); // Make two char hex code
    }

    return $return;
}




function filepress_fix_empty_title_issue($title=false, $instance=false) {
	 
  if (empty($title)) {
    $title = '<span class="widget_hide_me">--خالی--</span>';
  }
  return $title;
}
add_filter('widget_title','filepress_fix_empty_title_issue', 10, 2);	



function filepress_loginlogo_url($url) {
	return 'http://wd7.ir';
}
add_filter('login_headerurl', 'filepress_loginlogo_url', 99999999);

function filepress_footer_admin () {
 
echo 'متشکریم که از قالبهای  <a href="http://wd7.ir" target="_blank">وب دیزاین</a> استفاده می کنید.';
 
}
add_filter('admin_footer_text', 'filepress_footer_admin');


add_action('wp_dashboard_setup', 'filepress_dashboard_widgets');
function filepress_dashboard_widgets() {
     wp_add_dashboard_widget( 'dashboard_custom_feed', 'آخرین مطالب وب دیزاین' , 'dashboard_custom_feed_output' );
}
function dashboard_custom_feed_output() {
     echo '<div class="rss-widget">';
     wp_widget_rss_output(array(
          'url' => 'http://wd7.ir/feed',
          'title' => 'آخرین مطالب وب دیزاین',
          'items' => 2,
          'show_summary' => 1,
          'show_author' => 0,
          'show_date' => 1
     ));
     echo '</div>';
}


/**
 * Change Rial to ریال
 */
function filepress_edd_change_currency_sign( $formatted, $currency, $price ) {
return $price . ' ریال';
}
add_filter( 'edd_rial_currency_filter_after', 'filepress_edd_change_currency_sign', 10, 3 );
add_filter( 'edd_rial_currency_filter_before', 'filepress_edd_change_currency_sign', 10, 3 );

